@@ -8,7 +8,7 @@
 # 
 # Changes:     Moving the kernel tree to reflect the patch version
 
-kver="2.6.10"
+kver="2.6.11"
 kdir="/usr/src"
 wd=`pwd`
 
@@ -16,14 +16,14 @@ wd=`pwd`
 #mmfix="mmfix.patch"
 #bk="patch-2.6.4-rc1"
 
-ck="patch-2.6.10-ck2"
+ck="patch-2.6.11-ck1"
 #ck2="patch-O21int-ht4"
 #ck3="patch-ht4-batch5"
 #ck4="patch-2.6.0-am-5"
 
-ac="patch-2.6.10-ac7"
+#ac="patch-2.6.10-ac7"
 
-sm="supermount-2.0.4-2.6.10.patch"
+sm="supermount-2.0.4-2.6.11.patch"
 
 lirc="lirc-2.6.9-20040318"
 #lirc1="patch-lirc-20030806-test7_fix-bk.diff"
@@ -42,7 +42,7 @@ nvver="1.0-6629"
 nvrev="1.0.6629"
 nvdoc="/usr/share/doc"
 
-vt="VT6410.267.patch"
+vt="VT6410.2611.patch"
 lnx="patch-LNX"
 
 echo "This script is designed to help you patch your kernel."
@@ -125,12 +125,12 @@ echo
 
 #echo -ne "Apply mm patches (Recommended)? [Y/n]: Y\b"
 #echo -ne "Apply mm and ck performance patches (Recommended)? [Y/n]: Y\b"
-echo -ne "Apply ac7 and ck2 patches (Recommended)? [Y/n]: Y\b"
+echo -ne "Apply ck1 patches (Recommended)? [Y/n]: Y\b"
 choise="Y"
 read choise
 if [ "$choise" = "y" ] || [ "$choise" = "Y" ] || [ "$choise" = "" ];then
 	cd $kdir/linux-$kver
-	patch -p1 <$wd/$ac
+#	patch -p1 <$wd/$ac
 	patch -p1 <$wd/$ck
 #	patch -p1 <$wd/$ck2
 #	patch -p1 <$wd/$ck3
@@ -140,8 +140,8 @@ if [ "$choise" = "y" ] || [ "$choise" = "Y" ] || [ "$choise" = "" ];then
 	cd "$wd"
 #	packet="packet-2.6.0-test4.patch"
 ####	lirc="patch-lirc-20030802-test6_fix-mm.diff"
-	sm="supermount-2.0.4-2.6.10-ac7.patch"
-	vt="VT6410.267-ac7.patch"
+#	sm="supermount-2.0.4-2.6.10-ac7.patch"
+#	vt="VT6410.267-ac7.patch"
 fi
 echo
 ####else
@@ -266,11 +266,13 @@ echo
  	echo "Applying driver patches..."
  	cd $kdir/linux-$kver/drivers/char/nvidia/
  	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1155389.patch
- 	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1162524.patch
+ 	#patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1162524.patch
  	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1165235.patch
  	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1171869.patch
  	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1175225.patch
 	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1182399.patch
+	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1189413.patch
+	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1201042.diff
 	patch -p0 < $wd/1.0.6629/conftest_koutput_includes.patch
  	patch -p3 < $wd/1.0.6629/nv-disable-preempt-on-smp_processor_id.patch
 	patch -p3 < $wd/1.0.6629/NVIDIA_kernel-1.0-6629-1161283.patch
@@ -278,7 +280,7 @@ echo
  	cd "$wd"
  	echo -e "\n\033[01;31mImportant: Please say Y to the following unless:"
  	echo "1. You already installed GLX with THIS VERSION of the driver."
- 	echo -e "2. You're using Gentoo Linux -> emerge /usr/portage/media-video/nvidia-glx/nvidia-glx-$nvrev-r1.ebuild --nodeps -u\033[00m"
+ 	echo -e "2. You're using Gentoo Linux -> emerge /usr/portage/media-video/nvidia-glx/nvidia-glx-$nvrev-r5.ebuild --nodeps -u\033[00m"
  	echo -ne "\nInstall the nVIDIA GLX? [Y/n]: Y\b"
  	choise="Y"
  	read choise
